==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm2015/lib/ScatterPolylineSeriesDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { StyleDescriptionMetadata } from "./StyleDescriptionMetadata";
import { ShapeSeriesBaseDescriptionMetadata } from "./ShapeSeriesBaseDescriptionMetadata";
import { ScatterPolylineSeriesDescription } from "./ScatterPolylineSeriesDescription";
/**
 * @hidden
 */
export let ScatterPolylineSeriesDescriptionMetadata = /*@__PURE__*/ (() => {
    class ScatterPolylineSeriesDescriptionMetadata extends Base {
        static b(a) {
            if (ScatterPolylineSeriesDescriptionMetadata.a == null) {
                ScatterPolylineSeriesDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                ScatterPolylineSeriesDescriptionMetadata.c(ScatterPolylineSeriesDescriptionMetadata.a);
            }
            if (a.k(ScatterPolylineSeriesDescriptionMetadata.a)) {
                return;
            }
            a.ab(ScatterPolylineSeriesDescriptionMetadata.a);
            StyleDescriptionMetadata.d(a);
        }
        static c(a) {
            ShapeSeriesBaseDescriptionMetadata.c(a);
            a.item("ShapeStyle", "ExportedType:Style");
        }
        static d(a) {
            ScatterPolylineSeriesDescriptionMetadata.b(a);
            a.ad("ScatterPolylineSeries", () => new ScatterPolylineSeriesDescription());
            a.ac("ScatterPolylineSeries", ScatterPolylineSeriesDescriptionMetadata.a);
        }
    }
    ScatterPolylineSeriesDescriptionMetadata.$t = /*@__PURE__*/ markType(ScatterPolylineSeriesDescriptionMetadata, 'ScatterPolylineSeriesDescriptionMetadata');
    ScatterPolylineSeriesDescriptionMetadata.a = null;
    return ScatterPolylineSeriesDescriptionMetadata;
})();

==> igniteui-react-core-18.7.0-beta.2.tgz: package/esm2015/lib/ScatterPolylineSeriesDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { StyleDescriptionMetadata } from "./StyleDescriptionMetadata";
import { ShapeSeriesBaseDescriptionMetadata } from "./ShapeSeriesBaseDescriptionMetadata";
import { ScatterPolylineSeriesDescription } from "./ScatterPolylineSeriesDescription";
/**
 * @hidden
 */
export let ScatterPolylineSeriesDescriptionMetadata = /*@__PURE__*/ (() => {
    class ScatterPolylineSeriesDescriptionMetadata extends Base {
        static b(a) {
            if (ScatterPolylineSeriesDescriptionMetadata.a == null) {
                ScatterPolylineSeriesDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                ScatterPolylineSeriesDescriptionMetadata.c(ScatterPolylineSeriesDescriptionMetadata.a);
            }
            if (a.k(ScatterPolylineSeriesDescriptionMetadata.a)) {
                return;
            }
            a.ac(ScatterPolylineSeriesDescriptionMetadata.a);
            StyleDescriptionMetadata.d(a);
        }
        static c(a) {
            ShapeSeriesBaseDescriptionMetadata.c(a);
            a.item("ShapeStyle", "ExportedType:Style");
        }
        static d(a) {
            ScatterPolylineSeriesDescriptionMetadata.b(a);
            a.ae("ScatterPolylineSeries", () => new ScatterPolylineSeriesDescription());
            a.ad("ScatterPolylineSeries", ScatterPolylineSeriesDescriptionMetadata.a);
        }
    }
    ScatterPolylineSeriesDescriptionMetadata.$t = /*@__PURE__*/ markType(ScatterPolylineSeriesDescriptionMetadata, 'ScatterPolylineSeriesDescriptionMetadata');
    ScatterPolylineSeriesDescriptionMetadata.a = null;
    return ScatterPolylineSeriesDescriptionMetadata;
})();
